Locating samples and variants
=============================

.. automodule:: anhima.loc
.. autofunction:: view_sample
.. autofunction:: take_samples
.. autofunction:: query_variants
.. autofunction:: compress_variants
.. autofunction:: take_variants
.. autofunction:: locate_position
.. autofunction:: view_position
.. autofunction:: locate_interval
.. autofunction:: view_interval
.. autofunction:: locate_positions
.. autofunction:: locate_intervals
.. autofunction:: plot_variant_locator
.. autofunction:: windowed_variant_counts
.. autofunction:: plot_windowed_variant_counts
.. autofunction:: windowed_variant_density
.. autofunction:: plot_windowed_variant_density
.. autofunction:: windowed_statistic
.. autofunction:: evenly_downsample_variants
.. autofunction:: randomly_downsample_variants




